]> git.sesse.net Git - cubemap/blobdiff - server.h
Remove input encoding for UDP streams.
[cubemap] / server.h
index 7297fd7797daf3adaf73738da93eb861fca89ad6..b05f661aa6641d5aed95953b98b1d103fee8702f 100644 (file)
--- a/server.h
+++ b/server.h
@@ -48,20 +48,21 @@ public:
        // and the order between them are undefined.
        // XXX: header should ideally be ordered with respect to data.
        void add_client_deferred(int sock);
-       void add_data_deferred(int stream_index, const char *data, size_t bytes, StreamStartSuitability suitable_for_stream_start);
+       void add_data_deferred(int stream_index, const char *data, size_t bytes, uint16_t metacube_flags);
 
        // These should not be called while running, since that would violate
        // threading assumptions (ie., that epoll is only called from one thread
        // at the same time).
        CubemapStateProto serialize();
        void add_client_from_serialized(const ClientProto &client);
-       int add_stream(const std::string &url, size_t bytes_received, size_t prebuffering_bytes, Stream::Encoding encoding);
+       int add_stream(const std::string &url, size_t bytes_received, size_t prebuffering_bytes, Stream::Encoding encoding, Stream::Encoding src_encoding);
        int add_stream_from_serialized(const StreamProto &stream, int data_fd);
        int lookup_stream_by_url(const std::string &url) const;
        void set_backlog_size(int stream_index, size_t new_size);
        void set_prebuffering_bytes(int stream_index, size_t new_amount);
        void set_encoding(int stream_index, Stream::Encoding encoding);
-       void add_ping(const std::string &url, const std::string &allow_origin);
+       void set_src_encoding(int stream_index, Stream::Encoding encoding);
+       void add_gen204(const std::string &url, const std::string &allow_origin);
 
 private:
        // Mutex protecting queued_add_clients.
@@ -134,8 +135,7 @@ private:
        // Close a given client socket, and clean up after it.
        void close_client(Client *client);
 
// Parse the HTTP request. Returns a HTTP status code (200/400/404),
// or -200 for a pong (which should be answered with 200).
        int parse_request(Client *client);
 
        // Construct the HTTP header, and set the client into
@@ -146,8 +146,8 @@ private:
        // the SENDING_SHORT_RESPONSE state.
        void construct_error(Client *client, int error_code);
 
-       // Construct a pong, and set the client into the SENDING_SHORT_RESPONSE state.
-       void construct_pong(Client *client);
+       // Construct a 204, and set the client into the SENDING_SHORT_RESPONSE state.
+       void construct_204(Client *client);
 
        void process_queued_data();
        void skip_lost_data(Client *client);
@@ -134,8 +135,7 @@ private:
        void close_client(Client *client);
 
-       // Parse the HTTP request. Returns a HTTP status code (200/400/404),
-       // or -200 for a pong (which should be answered with 200).
+       // Parse the HTTP request. Returns a HTTP status code (200/204/400/404).
        int parse_request(Client *client);
 